@@ -52,9 +52,6 @@
 //C- | TO ANY WARRANTY OF NON-INFRINGEMENT, OR ANY IMPLIED WARRANTY OF
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
-// 
-// $Id: DjVuToPS.h,v 1.15 2007/03/25 20:48:31 leonb Exp $
-// $Name: release_3_5_23 $
 
 #ifndef _DJVU_TO_PS_H_
 #define _DJVU_TO_PS_H_
@@ -73,8 +70,6 @@
     @memo PostScript file generator
     @author Andrei Erofeev <eaf@geocities.com> \\
             Florin Nicsa <Florin.Nicsa@insa-lyon.fr>
-    @version
-    #$Id: DjVuToPS.h,v 1.15 2007/03/25 20:48:31 leonb Exp $#
 */
 //@{
 
